@@ -1,3 +1,4 @@
+use clap_complete::Shell;
 use dua::ByteFormat as LibraryByteFormat;
 use std::path::PathBuf;
 
@@ -106,7 +107,7 @@ pub enum Command {
         #[clap(value_parser)]
         input: Vec<PathBuf>,
     },
-    /// Aggregrate the consumed space of one or more directories or files
+    /// Aggregate the consumed space of one or more directories or files
     #[clap(name = "aggregate", visible_alias = "a")]
     Aggregate {
         /// If set, print additional statistics about the file traversal to stderr
@@ -123,4 +124,9 @@ pub enum Command {
         #[clap(value_parser)]
         input: Vec<PathBuf>,
     },
+    /// Generate shell completions
+    Completions {
+        /// The shell to generate a completions-script for
+        shell: Shell,
+    },
 }
